Finds the lowest complexity parameter for a null regression tree fit
get_mnpp.classtree(z, data, Trt, Y, threshold)the MNPP
a numeric vector of estimated CATEs from Step 1
a data frame containing a response, binary treatment indicators, and covariates.
a string specifying the name of the column of data
contains the treatment indicators.
a string specifying the name of the column of data
contains the response.
for "step2 = 'classtree'" only. The value against
which to test if the estimated individual treatment effect from Step 1 is
higher (TRUE) or lower (FALSE).