Estimate the CATE using a classification tree for Step 2
vt2_classtree(z, data, Trt, Y, theta, threshold)an object of class rpart. See
rpart.object.
a numeric vector of estimated CATEs from Step 1
a data frame containing a response, binary treatment indicators, and covariates.
a string specifying the name of the column of data
contains the treatment indicators.
a string specifying the name of the column of data
contains the response.
tree complexity parameter (cp)
for "step2 = 'classtree'" only. The value against
which to test if the estimated individual treatment effect from Step 1 is
higher (TRUE) or lower (FALSE).
Other VT Step 2 functions:
vt2_ctree(),
vt2_lasso(),
vt2_rtree()